==> jc-1.4.0.tar.gz: javax/swing/filechooser/FileFilter.h <==
// public abstract class javax.swing.filechooser.FileFilter

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 417457cb864042ae javax_swing_filechooser_FileFilter

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_filechooser_FileFilter_H_
#define _JC_javax_swing_filechooser_FileFilter_H_

// Forward structure declarations
struct _jc_java_io_File$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_swing_filechooser_FileFilter$sub_refs	_jc_javax_swing_filechooser_FileFilter$sub_refs;
typedef struct _jc_javax_swing_filechooser_FileFilter$sub_nonrefs	_jc_javax_swing_filechooser_FileFilter$sub_nonrefs;
typedef struct _jc_javax_swing_filechooser_FileFilter$refs	_jc_javax_swing_filechooser_FileFilter$refs;
typedef struct _jc_javax_swing_filechooser_FileFilter$nonrefs	_jc_javax_swing_filechooser_FileFilter$nonrefs;
typedef struct _jc_javax_swing_filechooser_FileFilter$object	_jc_javax_swing_filechooser_FileFilter$object;

typedef const struct _jc_javax_swing_filechooser_FileFilter$vmethods	_jc_javax_swing_filechooser_FileFilter$vmethods;
typedef const struct _jc_javax_swing_filechooser_FileFilter$vtable	_jc_javax_swing_filechooser_FileFilter$vtable;
typedef const struct _jc_javax_swing_filechooser_FileFilter$vtype	_jc_javax_swing_filechooser_FileFilter$vtype;

// Constructors
extern void _jc_javax_swing_filechooser_FileFilter$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_filechooser_FileFilter$object *);

// Virtual methods
extern jboolean _jc_javax_swing_filechooser_FileFilter$method$accept$0a515218e13a3730(_jc_env *, struct _jc_javax_swing_filechooser_FileFilter$object *, struct _jc_java_io_File$object *);
extern struct _jc_java_lang_String$object *_jc_javax_swing_filechooser_FileFilter$method$getDescription$2661fc1f3e986b4b(_jc_env *, struct _jc_javax_swing_filechooser_FileFilter$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_filechooser_FileFilter$method_info$accept$0a515218e13a3730;
extern _jc_method _jc_javax_swing_filechooser_FileFilter$method_info$getDescription$2661fc1f3e986b4b;

// Virtual methods structure
struct _jc_javax_swing_filechooser_FileFilter$vmethods {
	jboolean	(*accept$0a515218e13a3730)(_jc_env *, struct _jc_javax_swing_filechooser_FileFilter$object *, struct _jc_java_io_File$object *);
	struct _jc_java_lang_String$object	*(*getDescription$2661fc1f3e986b4b)(_jc_env *, struct _jc_javax_swing_filechooser_FileFilter$object *);
};

// Vtable
struct _jc_javax_swing_filechooser_FileFilter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_filechooser_FileFilter$vmethods	javax_swing_filechooser_FileFilter;
};

// Vtype
struct _jc_javax_swing_filechooser_FileFilter$vtype {
	_jc_type			type;
	_jc_javax_swing_filechooser_FileFilter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_filechooser_FileFilter$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_filechooser_FileFilter$refs {
    _jc_javax_swing_filechooser_FileFilter$sub_refs	javax_swing_filechooser_FileFilter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_filechooser_FileFilter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_filechooser_FileFilter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_filechooser_FileFilter$sub_nonrefs	javax_swing_filechooser_FileFilter;
};

// Object instance structure
struct _jc_javax_swing_filechooser_FileFilter$object {
	_jc_javax_swing_filechooser_FileFilter$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_filechooser_FileFilter$vtype	*vtype;
	_jc_javax_swing_filechooser_FileFilter$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_filechooser_FileFilter$vtype _jc_javax_swing_filechooser_FileFilter$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_filechooser_FileFilter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_filechooser_FileFilter$class_object;

#endif	/* _JC_javax_swing_filechooser_FileFilter_H_ */

==> jc-1.4.6.tar.gz: javax/swing/filechooser/FileFilter.h <==
// public abstract class javax.swing.filechooser.FileFilter

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 417457cb864042ae javax_swing_filechooser_FileFilter

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_filechooser_FileFilter_H_
#define _JC_javax_swing_filechooser_FileFilter_H_

// Forward structure declarations
struct _jc_java_io_File$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_swing_filechooser_FileFilter$sub_refs	_jc_javax_swing_filechooser_FileFilter$sub_refs;
typedef struct _jc_javax_swing_filechooser_FileFilter$sub_nonrefs	_jc_javax_swing_filechooser_FileFilter$sub_nonrefs;
typedef struct _jc_javax_swing_filechooser_FileFilter$refs	_jc_javax_swing_filechooser_FileFilter$refs;
typedef struct _jc_javax_swing_filechooser_FileFilter$nonrefs	_jc_javax_swing_filechooser_FileFilter$nonrefs;
typedef struct _jc_javax_swing_filechooser_FileFilter$object	_jc_javax_swing_filechooser_FileFilter$object;

typedef const struct _jc_javax_swing_filechooser_FileFilter$vmethods	_jc_javax_swing_filechooser_FileFilter$vmethods;
typedef const struct _jc_javax_swing_filechooser_FileFilter$vtable	_jc_javax_swing_filechooser_FileFilter$vtable;
typedef const struct _jc_javax_swing_filechooser_FileFilter$vtype	_jc_javax_swing_filechooser_FileFilter$vtype;

// Constructors
extern void _jc_javax_swing_filechooser_FileFilter$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_filechooser_FileFilter$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_javax_swing_filechooser_FileFilter$method$accept$0a515218e13a3730(_jc_env *, struct _jc_javax_swing_filechooser_FileFilter$object *, struct _jc_java_io_File$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_swing_filechooser_FileFilter$method$getDescription$2661fc1f3e986b4b(_jc_env *, struct _jc_javax_swing_filechooser_FileFilter$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_filechooser_FileFilter$method_info$accept$0a515218e13a3730;
extern _jc_method _jc_javax_swing_filechooser_FileFilter$method_info$getDescription$2661fc1f3e986b4b;

// Virtual methods structure
struct _jc_javax_swing_filechooser_FileFilter$vmethods {
	jboolean	(*accept$0a515218e13a3730)(_jc_env *, struct _jc_javax_swing_filechooser_FileFilter$object *, struct _jc_java_io_File$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getDescription$2661fc1f3e986b4b)(_jc_env *, struct _jc_javax_swing_filechooser_FileFilter$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_filechooser_FileFilter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_filechooser_FileFilter$vmethods	javax_swing_filechooser_FileFilter;
};

// Vtype
struct _jc_javax_swing_filechooser_FileFilter$vtype {
	_jc_type			type;
	_jc_javax_swing_filechooser_FileFilter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_filechooser_FileFilter$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_filechooser_FileFilter$refs {
    _jc_javax_swing_filechooser_FileFilter$sub_refs	javax_swing_filechooser_FileFilter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_filechooser_FileFilter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_filechooser_FileFilter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_filechooser_FileFilter$sub_nonrefs	javax_swing_filechooser_FileFilter;
};

// Object instance structure
struct _jc_javax_swing_filechooser_FileFilter$object {
	_jc_javax_swing_filechooser_FileFilter$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_filechooser_FileFilter$vtype	*vtype;
	_jc_javax_swing_filechooser_FileFilter$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_filechooser_FileFilter$vtype _jc_javax_swing_filechooser_FileFilter$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_filechooser_FileFilter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_filechooser_FileFilter$class_object;

#endif	/* _JC_javax_swing_filechooser_FileFilter_H_ */
